Package 'rk.lubridate'

Title: An RKWard plugin package for working with dates and times data using the 'lubridate' library.
Description: An RKWard plugin package for working with dates and times data using the 'lubridate' library.
Authors: Alfonso Cano Robles
Maintainer: Alfonso Cano Robles <[email protected]>
License: GPL (>= 3)
Version: 0.0.5
Built: 2026-06-04 10:04:20 UTC
Source: https://github.com/AlfCano/rk.lubridate

Help Index